<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "アドレス帳の有効／無効化に失敗しました。",
"id is not set." => "idが設定されていません。",
"Cannot update addressbook with an empty name." => "空白の名前でアドレス帳を更新することはできません。",
"No category name given." => "カテゴリ名が指定されていません。",
"Error adding group." => "グループの追加エラー。",
"Group ID missing from request." => "リクエストにはグループIDがありません。",
"Contact ID missing from request." => "リクエストには連絡先IDがありません。",
"No ID provided" => "IDが提供されていません",
"Error setting checksum." => "チェックサムの設定エラー。",
"No categories selected for deletion." => "削除するカテゴリが選択されていません。",
"No address books found." => "アドレス帳が見つかりません。",
"No contacts found." => "連絡先が見つかりません。",
"element name is not set." => "要素名が設定されていません。",
"checksum is not set." => "チェックサムが設定されていません。",
"Information about vCard is incorrect. Please reload the page." => "vCardの情報に誤りがあります。ページをリロードして下さい。",
"Couldn't find vCard for %d." => "%d のvCardが見つかりませんでした。",
"Information about vCard is incorrect. Please reload the page: " => "vCardの情報が正しくありません。ページを再読み込みしてください: ",
"Something went FUBAR. " => "何かがFUBARへ移動しました。",
"Cannot save property of type \"%s\" as array" => "\"%s\" タイプのプロパティを配列として保存できません",
"Missing IM parameter." => "IMのパラメータが不足しています。",
"Unknown IM: " => "不明なIM:",
"No contact ID was submitted." => "連絡先IDは登録されませんでした。",
"Error reading contact photo." => "連絡先写真の読み込みエラー。",
"Error saving temporary file." => "一時ファイルの保存エラー。",
"The loading photo is not valid." => "写真の読み込みは無効です。",
"Contact ID is missing." => "連絡先 IDが見つかりません。",
"No photo path was submitted." => "写真のパスが登録されていません。",
"File doesn't exist:" => "ファイルが存在しません:",
"Error loading image." => "画像の読み込みエラー。",
"Error getting contact object." => "連絡先オブジェクトの取得エラー。",
"Error getting PHOTO property." => "写真属性の取得エラー。",
"Error saving contact." => "連絡先の保存エラー。",
"Error resizing image" => "画像のリサイズエラー",
"Error cropping image" => "画像の切り抜きエラー",
"Error creating temporary image" => "一時画像の生成エラー",
"Error finding image: " => "画像検索エラー: ",
"Key is not set for: " => "キーが未設定:",
"Value is not set for: " => "値が未設定:",
"Could not set preference: " => "優先度を設定出来ません: ",
"Error uploading contacts to storage." => "ストレージへの連絡先のアップロードエラー。",
"There is no error, the file uploaded with success" => "エラーはありません。ファイルのアップロードは成功しました",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "アップロードファイルは php.ini 内の upload_max_filesize の制限を超えています",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "アップロードファイルはHTMLフォームで指定された MAX_FILE_SIZE の制限を超えています",
"The uploaded file was only partially uploaded" => "アップロードファイルは一部分だけアップロードされました",
"No file was uploaded" => "ファイルはアップロードされませんでした",
"Missing a temporary folder" => "一時保存フォルダが見つかりません",
"Couldn't save temporary image: " => "一時的な画像の保存ができませんでした: ",
"Couldn't load temporary image: " => "一時的な画像の読み込みができませんでした: ",
"No file was uploaded. Unknown error" => "ファイルは何もアップロードされていません。不明なエラー",
"Contacts" => "連絡先",
"%d_selected_contacts" => "%d個の選択された連絡先",
"Add to..." => "追加...",
"Remove from..." => "削除...",
"Add group..." => "グループを追加...",
"Indexing contacts" => "連絡先のインデックスを作成中",
"Select photo" => "写真を選択",
"Network or server error. Please inform administrator." => "ネットワークもしくはサーバエラーです。管理者に連絡してください。",
"Error adding to group." => "グループに追加エラー。",
"Error removing from group." => "グループから削除エラー。",
"There was an error opening a mail composer." => "メールコンポーザの起動エラーが発生しました。",
"Deleting done. Click here to cancel reloading." => "削除完了。再読込みをキャンセルする場合はここをクリック。",
"Add address book" => "アドレスブックを追加",
"Import done. Click here to cancel reloading." => "インポート完了。再読込みをキャンセルする場合はここをクリック。",
"Not all files uploaded. Retrying..." => "ファイルがアップロード出来ませんでした。再実行中...。",
"Something went wrong with the upload, please retry." => "アップロード中に不具合が発生しました、再実行してください。",
"Error" => "エラー",
"Importing from {filename}..." => "{filename} からインポート中...",
"{success} imported, {failed} failed." => "{success} をインポート､{failed} は失敗しました。",
"Importing..." => "インポート中...",
"Unable to upload your file as it is a directory or has 0 bytes" => "ディレクトリもしくは0バイトのファイルはアップロードできません",
"Upload Error" => "アップロードエラー",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "アップロードしようとしているファイルは、このサーバの最大ファイルアップロードサイズを超えています。",
"Upload too large" => "アップロードには大きすぎます。",
"Pending" => "中断",
"Add group" => "グループを追加",
"No files selected for upload." => "アップロードするファイルが選択されていません。",
"Edit profile picture" => "プロフィール写真を編集",
"Error loading profile picture." => "プロファイルの画像の読み込みエラー",
"Enter name" => "名前を入力",
"Enter description" => "説明を入力してください",
"Select addressbook" => "アドレスブックを選択",
"The address book name cannot be empty." => "アドレス帳名は空に出来ません。",
"Is this correct?" => "これは正しいですか？",
"There was an unknown error when trying to delete this contact" => "この連絡先の削除時に不明なエラーが発生しました",
"# groups" => "グループ数",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "いくつかの連絡先が削除対象としてマークされていますが、まだ削除されていません。削除するまでお待ちください。",
"Click to undo deletion of {num} contacts" => "{num} 個の連絡先の削除を元に戻す",
"Cancelled deletion of {num}" => "{num} 個の削除をキャンセルしました",
"Contact is already in this group." => "連絡先はすでにこのグループに存在します。",
"Contacts are already in this group." => "連絡先はすでにこのグループに存在します。",
"Couldn't get contact list." => "連絡先リストを取得できませんでした。",
"Contact is not in this group." => "連絡先はこのグループに存在しません。",
"Contacts are not in this group." => "連絡先はこのグループに存在しません。",
"A group named {group} already exists" => "{group} のグループはすでに存在します",
"You can drag groups to\narrange them as you like." => "グループをドラックすることで好きな\nように並べ替えることができます。",
"All" => "すべて",
"Favorites" => "お気に入り",
"Shared by {owner}" => "{owner} と共有中",
"Result: " => "結果: ",
" imported, " => " をインポート、 ",
" failed." => " は失敗しました。",
"Displayname cannot be empty." => "表示名は空にできません。",
"Show CardDav link" => "CarDavリンクを表示",
"Show read-only VCF link" => "読み取り専用のVCFリンクを表示",
"Download" => "ダウンロード",
"Edit" => "編集",
"Delete" => "削除",
"Cancel" => "取り消し",
"More..." => "もっと...",
"Less..." => "簡略...",
"You do not have the permissions to read this addressbook." => "このアドレス帳を見る権限がありません。",
"You do not have the permissions to update this addressbook." => "アドレス帳を更新する権限がありません",
"There was an error updating the addressbook." => "アドレス帳を更新中にエラーが発生しました。",
"You do not have the permissions to delete this addressbook." => "アドレス帳を削除する権限がありません。",
"There was an error deleting this addressbook." => "アドレス帳を削除するときにエラーが発生しました。",
"Jabber" => "Jabber",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "Googleトーク",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "勤務先",
"Home" => "住居",
"Other" => "その他",
"Mobile" => "携帯電話",
"Text" => "TTY TDD",
"Voice" => "音声番号",
"Message" => "メッセージ",
"Fax" => "FAX",
"Video" => "テレビ電話",
"Pager" => "ポケベル",
"Internet" => "インターネット",
"Friends" => "友達",
"Family" => "家族",
"There was an error deleting properties for this contact." => "この連絡先のプロパティの削除エラーが発生しました。",
"{name}'s Birthday" => "{name}の誕生日",
"Contact" => "連絡先",
"You do not have the permissions to add contacts to this addressbook." => "アドレスブックに連絡先を追加する権限がありません",
"Could not find the vCard with ID." => "そのIDのvCardが見つかりませんでした。",
"You do not have the permissions to edit this contact." => "この連絡先を編集する権限がありません",
"Could not find the vCard with ID: " => "そのIDのvCardが見つかりませんでした：",
"Could not find the Addressbook with ID: " => "そのIDのアドレス帳が見つかりませんでした：",
"You do not have the permissions to delete this contact." => "この連絡先を削除する権限がありません",
"There was an error deleting this contact." => "連絡先を削除するときにエラーが発生しました。",
"Contact not found." => "連絡先が見つかりません。",
"HomePage" => "ホームページ",
"New Group" => "新しいグループ",
"Settings" => "設定",
"Address books" => "アドレスブック",
"Import" => "インポート",
"Select files to import" => "インポートするファイルを選択",
"Select files" => "ファイルを選択",
"Import into:" => "インポート情報:",
"OK" => "OK",
"(De-)select all" => "すべての選択を解除",
"New Contact" => "新しい連絡先",
"Download Contact(s)" => "連絡先をダウンロード",
"Groups" => "グループ",
"Favorite" => "お気に入り",
"Delete Contact" => "連絡先を削除",
"Close" => "閉じる",
"Keyboard shortcuts" => "キーボードショートカット",
"Navigation" => "ナビゲーション",
"Next contact in list" => "リスト内の次の連絡先",
"Previous contact in list" => "リスト内の前の連絡先",
"Expand/collapse current addressbook" => "現在のアドレス帳を展開する／折りたたむ",
"Next addressbook" => "次のアドレス帳",
"Previous addressbook" => "前のアドレス帳",
"Actions" => "アクション",
"Refresh contacts list" => "連絡先リストを再読込する",
"Add new contact" => "新しい連絡先を追加",
"Add new addressbook" => "新しいアドレス帳を追加",
"Delete current contact" => "現在の連絡先を削除",
"<h3>You have no contacts in your addressbook.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>アドレスブックに連絡先がありません。</h3><p>新しい連絡先を追加、もしくは既存の連絡先をVCFファイルからインポートしてください。</p>",
"Add contact" => "連絡先を追加",
"Compose mail" => "メールを作成",
"Delete group" => "グループを削除",
"Delete current photo" => "現在の写真を削除",
"Edit current photo" => "現在の写真を編集",
"Upload new photo" => "新しい写真をアップロード",
"Select photo from ownCloud" => "ownCloudから写真を選択",
"First name" => "名",
"Additional names" => "ミドルネーム",
"Last name" => "姓",
"Select groups" => "グループを選択",
"Nickname" => "ニックネーム",
"Enter nickname" => "ニックネームを入力",
"Title" => "タイトル",
"Enter title" => "タイトルを入力",
"Organization" => "所属",
"Enter organization" => "組織を入力",
"Birthday" => "誕生日",
"Notes go here..." => "メモはここに...",
"Export as VCF" => "VCFとしてエクスポート",
"Add" => "追加",
"Phone" => "電話番号",
"Email" => "メールアドレス",
"Instant Messaging" => "インスタントメッセージ",
"Address" => "住所",
"Note" => "メモ",
"Web site" => "ウェブサイト",
"Delete contact" => "連絡先の削除",
"Preferred" => "推奨",
"Please specify a valid email address." => "有効なメールアドレスを指定してください。",
"someone@example.com" => "someone@example.com",
"Mail to address" => "アドレスへメールを送る",
"Delete email address" => "メールアドレスを削除",
"Enter phone number" => "電話番号を入力",
"Delete phone number" => "電話番号を削除",
"Go to web site" => "Webサイトへ移動",
"Delete URL" => "URLを削除",
"View on map" => "地図で表示",
"Delete address" => "住所を削除",
"1 Main Street" => "番地",
"Street address" => "住所1",
"12345" => "12345",
"Postal code" => "郵便番号",
"Your city" => "市",
"City" => "都市",
"Some region" => "都道府県",
"State or province" => "州／県",
"Your country" => "国",
"Country" => "国名",
"Instant Messenger" => "インスタントメッセンジャー",
"Delete IM" => "IMを削除",
"Share" => "共有",
"Export" => "エクスポート",
"CardDAV link" => "CardDAVリンク",
"The temporary image has been removed from cache." => "一時画像はキャッシュから削除されました。",
"CardDAV syncing addresses" => "CardDAV同期アドレス",
"more info" => "詳細情報",
"Primary address (Kontact et al)" => "プライマリアドレス（Kontact 他）",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "アドレス帳",
"New Address Book" => "新規のアドレス帳",
"Name" => "名前",
"Description" => "説明",
"Save" => "保存"
);
